@@ -1,10 +1,12 @@
 OC.L10N.register(
     "notes",
     {
+    "Reading notes from filesystem has failed." : "קריאת הפתקים ממערכת הקבצים נכשלה.",
     "Error" : "שגיאה",
     "New note" : "פתק חדש",
     "Notes" : "הערות",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
+    "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
     "Deleted {title}" : "{title} נמחק",
     "Deleted {number} notes" : "נמחקו {number} פתקים",
     "Undo Delete" : "ביטול מחיקה",
@@ -35,6 +37,7 @@ OC.L10N.register(
     "Empty note" : "פתק ריק",
     "Write …" : "כתיבה…",
     "Details" : "פרטים",
+    "CTRL + /" : "CTRL + /‎",
     "Edit" : "עריכה",
     "Preview" : "תצוגה מקדימה",
     "Exit full screen" : "יציאה ממסך מלא",
@@ -49,6 +52,7 @@ OC.L10N.register(
     "Note has unsaved changes" : "יש שינויים בפתק שטרם נשמרו",
     "Subcategory" : "תת־קטגוריה",
     "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
+    "_%n character_::_%n characters_" : ["תו אחד","%n תווים","%n תווים","%n תווים"],
     "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
     "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
     "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
@@ -57,12 +61,19 @@ OC.L10N.register(
     "iOS app" : "יישומון ל־iOS",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "ניתן ליצור תת־קטגוריות על ידי שימוש ב־„/” כמפריד בין קטגוריית ההורה ותת־הקטגוריה, למשל: „‎{parent}/{sub}‎”.",
+    "Note not found." : "הפתק לא נמצא.",
+    "Note is locked." : "הפתק נעול.",
+    "Insufficient storage." : "אין מספיק שטח אחסון.",
     "See JavaScript console and server log for details." : "ניתן להביט במסוף ה־JavaScript וביומן השרת לקבלת פרטים.",
     "Updating settings has failed." : "עדכון ההגדרות נכשל.",
+    "Error from Nextcloud server: {msg}" : "שגיאה משרת ה־Nextcloud:‏ {msg}",
     "Fetching notes has failed." : "קבלת הפתקים נכשלה.",
     "Fetching note {id} has failed." : "קבלת הפתק {id} נכשלה.",
+    "Refreshing note {id} has failed." : "רענון הפתק {id} נכשל.",
     "Renaming note {id} has failed." : "שינוי שם הפתק {id} נכשל.",
     "Creating new note has failed." : "יצירת פתק חדש נכשלה.",
+    "Saving note {id} has failed." : "שמירת הפתק {id} נכשלה.",
+    "Updating title for note {id} has failed." : "עדכון כותרת הפתק {id} נכשלה.",
     "Undo delete has failed for note {title}." : "ביטול מחיקת הפתק {title} נכשלה.",
     "Deleting note {id} has failed." : "מחיקת הפתק {id} נכשלה.",
     "Toggling favorite for note {id} has failed." : "החלפת מצב העדפה לפתק {id} נכשלה.",
