@@ -1,9 +1,10 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "Eslatmalar",
-    "New note" : "Yangi eslatma",
     "Error" : "Xato",
-    "Settings" : "Sozlamalar"
+    "New note" : "Yangi eslatma",
+    "Notes" : "Eslatmalar",
+    "Settings" : "Sozlamalar",
+    "Rename" : "Nomni o'zgartiring"
 },
 "nplurals=1; plural=0;");
